# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["SharepointConnectorConfig"]


class SharepointConnectorConfig(BaseModel):
    client_id: str

    client_secret: str

    name: str

    sharepoint_site_name: str

    tenant_id: str

    type: Optional[Literal["SharepointDataSourceManager"]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, Required, TypedDict

__all__ = ["QdrantConnectorConfigParam", "IndexInfo"]


class IndexInfo(TypedDict, total=False):
    total_indexes_found: Required[int]


class QdrantConnectorConfigParam(TypedDict, total=False):
    api_key: Required[str]

    collection_name: Required[str]

    name: Required[str]

    url: Required[str]

    filename_key: str

    index_info: Optional[IndexInfo]

    text_key: str

    type: Literal["QdrantVectorDBManager"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, Union, Mapping
from typing_extensions import Self, override

import httpx

from . import _exceptions
from ._qs import Querystring
from ._types import (
    NOT_GIVEN,
    Omit,
    Timeout,
    NotGiven,
    Transport,
    ProxiesTypes,
    RequestOptions,
)
from ._utils import (
    is_given,
    get_async_library,
)
from ._version import __version__
from .resources import (
    tags,
    schema,
    classify,
    metadata,
    deasy_select,
    prepare_data,
    classify_bulk,
    llm_connector,
    vdb_connector,
    suggest_schema,
    suggest_description,
)
from ._streaming import Stream as Stream, AsyncStream as AsyncStream
from ._exceptions import DeasyError, APIStatusError
from ._base_client import (
    DEFAULT_MAX_RETRIES,
    SyncAPIClient,
    AsyncAPIClient,
)
from .resources.dataslice import dataslice

__all__ = ["Timeout", "Transport", "ProxiesTypes", "RequestOptions", "Deasy", "AsyncDeasy", "Client", "AsyncClient"]


class Deasy(SyncAPIClient):
    deasy_select: deasy_select.DeasySelectResource
    classify_bulk: classify_bulk.ClassifyBulkResource
    classify: classify.ClassifyResource
    prepare_data: prepare_data.PrepareDataResource
    suggest_schema: suggest_schema.SuggestSchemaResource
    suggest_description: suggest_description.SuggestDescriptionResource
    tags: tags.TagsResource
    metadata: metadata.MetadataResource
    vdb_connector: vdb_connector.VdbConnectorResource
    llm_connector: llm_connector.LlmConnectorResource
    dataslice: dataslice.DatasliceResource
    schema: schema.SchemaResource
    with_raw_response: DeasyWithRawResponse
    with_streaming_response: DeasyWithStreamedResponse

    # client options
    x_token: str
    x_user: str

    def __init__(
        self,
        *,
        x_token: str | None = None,
        x_user: str,
        base_url: str | httpx.URL | None = None,
        timeout: Union[float, Timeout, None, NotGiven] = NOT_GIVEN,
        max_retries: int = DEFAULT_MAX_RETRIES,
        default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        # Configure a custom httpx client.
        # We provide a `DefaultHttpxClient` class that you can pass to retain the default values we use for `limits`, `timeout` & `follow_redirects`.
        # See the [httpx documentation](https://www.python-httpx.org/api/#client) for more details.
        http_client: httpx.Client | None = None,
        # Enable or disable schema validation for data returned by the API.
        # When enabled an error APIResponseValidationError is raised
        # if the API responds with invalid data for the expected schema.
        #
        # This parameter may be removed or changed in the future.
        # If you rely on this feature, please open a GitHub issue
        # outlining your use-case to help us decide if it should be
        # part of our public interface in the future.
        _strict_response_validation: bool = False,
    ) -> None:
        """Construct a new synchronous Deasy client instance.

        This automatically infers the `x_token` argument from the `DEASY_API_KEY` environment variable if it is not provided.
        """
        if x_token is None:
            x_token = os.environ.get("DEASY_API_KEY")
        if x_token is None:
            raise DeasyError(
                "The x_token client option must be set either by passing x_token to the client or by setting the DEASY_API_KEY environment variable"
            )
        self.x_token = x_token

        self.x_user = x_user

        if base_url is None:
            base_url = os.environ.get("DEASY_BASE_URL")
        if base_url is None:
            base_url = f"https://prod-deasy-api-service-660949837227.us-east1.run.app/"

        super().__init__(
            version=__version__,
            base_url=base_url,
            max_retries=max_retries,
            timeout=timeout,
            http_client=http_client,
            custom_headers=default_headers,
            custom_query=default_query,
            _strict_response_validation=_strict_response_validation,
        )

        self.deasy_select = deasy_select.DeasySelectResource(self)
        self.classify_bulk = classify_bulk.ClassifyBulkResource(self)
        self.classify = classify.ClassifyResource(self)
        self.prepare_data = prepare_data.PrepareDataResource(self)
        self.suggest_schema = suggest_schema.SuggestSchemaResource(self)
        self.suggest_description = suggest_description.SuggestDescriptionResource(self)
        self.tags = tags.TagsResource(self)
        self.metadata = metadata.MetadataResource(self)
        self.vdb_connector = vdb_connector.VdbConnectorResource(self)
        self.llm_connector = llm_connector.LlmConnectorResource(self)
        self.dataslice = dataslice.DatasliceResource(self)
        self.schema = schema.SchemaResource(self)
        self.with_raw_response = DeasyWithRawResponse(self)
        self.with_streaming_response = DeasyWithStreamedResponse(self)

    @property
    @override
    def qs(self) -> Querystring:
        return Querystring(array_format="comma")

    @property
    @override
    def default_headers(self) -> dict[str, str | Omit]:
        return {
            **super().default_headers,
            "X-Stainless-Async": "false",
            "X-Token": self.x_token,
            "X-User": self.x_user,
            **self._custom_headers,
        }

    def copy(
        self,
        *,
        x_token: str | None = None,
        x_user: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = NOT_GIVEN,
        http_client: httpx.Client | None = None,
        max_retries: int | NotGiven = NOT_GIVEN,
        default_headers: Mapping[str, str] | None = None,
        set_default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        set_default_query: Mapping[str, object] | None = None,
        _extra_kwargs: Mapping[str, Any] = {},
    ) -> Self:
        """
        Create a new client instance re-using the same options given to the current client with optional overriding.
        """
        if default_headers is not None and set_default_headers is not None:
            raise ValueError("The `default_headers` and `set_default_headers` arguments are mutually exclusive")

        if default_query is not None and set_default_query is not None:
            raise ValueError("The `default_query` and `set_default_query` arguments are mutually exclusive")

        headers = self._custom_headers
        if default_headers is not None:
            headers = {**headers, **default_headers}
        elif set_default_headers is not None:
            headers = set_default_headers

        params = self._custom_query
        if default_query is not None:
            params = {**params, **default_query}
        elif set_default_query is not None:
            params = set_default_query

        http_client = http_client or self._client
        return self.__class__(
            x_token=x_token or self.x_token,
            x_user=x_user or self.x_user,
            base_url=base_url or self.base_url,
            timeout=self.timeout if isinstance(timeout, NotGiven) else timeout,
            http_client=http_client,
            max_retries=max_retries if is_given(max_retries) else self.max_retries,
            default_headers=headers,
            default_query=params,
            **_extra_kwargs,
        )

    # Alias for `copy` for nicer inline usage, e.g.
    # client.with_options(timeout=10).foo.create(...)
    with_options = copy

    @override
    def _make_status_error(
        self,
        err_msg: str,
        *,
        body: object,
        response: httpx.Response,
    ) -> APIStatusError:
        if response.status_code == 400:
            return _exceptions.BadRequestError(err_msg, response=response, body=body)

        if response.status_code == 401:
            return _exceptions.AuthenticationError(err_msg, response=response, body=body)

        if response.status_code == 403:
            return _exceptions.PermissionDeniedError(err_msg, response=response, body=body)

        if response.status_code == 404:
            return _exceptions.NotFoundError(err_msg, response=response, body=body)

        if response.status_code == 409:
            return _exceptions.ConflictError(err_msg, response=response, body=body)

        if response.status_code == 422:
            return _exceptions.UnprocessableEntityError(err_msg, response=response, body=body)

        if response.status_code == 429:
            return _exceptions.RateLimitError(err_msg, response=response, body=body)

        if response.status_code >= 500:
            return _exceptions.InternalServerError(err_msg, response=response, body=body)
        return APIStatusError(err_msg, response=response, body=body)


class AsyncDeasy(AsyncAPIClient):
    deasy_select: deasy_select.AsyncDeasySelectResource
    classify_bulk: classify_bulk.AsyncClassifyBulkResource
    classify: classify.AsyncClassifyResource
    prepare_data: prepare_data.AsyncPrepareDataResource
    suggest_schema: suggest_schema.AsyncSuggestSchemaResource
    suggest_description: suggest_description.AsyncSuggestDescriptionResource
    tags: tags.AsyncTagsResource
    metadata: metadata.AsyncMetadataResource
    vdb_connector: vdb_connector.AsyncVdbConnectorResource
    llm_connector: llm_connector.AsyncLlmConnectorResource
    dataslice: dataslice.AsyncDatasliceResource
    schema: schema.AsyncSchemaResource
    with_raw_response: AsyncDeasyWithRawResponse
    with_streaming_response: AsyncDeasyWithStreamedResponse

    # client options
    x_token: str
    x_user: str

    def __init__(
        self,
        *,
        x_token: str | None = None,
        x_user: str,
        base_url: str | httpx.URL | None = None,
        timeout: Union[float, Timeout, None, NotGiven] = NOT_GIVEN,
        max_retries: int = DEFAULT_MAX_RETRIES,
        default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        # Configure a custom httpx client.
        # We provide a `DefaultAsyncHttpxClient` class that you can pass to retain the default values we use for `limits`, `timeout` & `follow_redirects`.
        # See the [httpx documentation](https://www.python-httpx.org/api/#asyncclient) for more details.
        http_client: httpx.AsyncClient | None = None,
        # Enable or disable schema validation for data returned by the API.
        # When enabled an error APIResponseValidationError is raised
        # if the API responds with invalid data for the expected schema.
        #
        # This parameter may be removed or changed in the future.
        # If you rely on this feature, please open a GitHub issue
        # outlining your use-case to help us decide if it should be
        # part of our public interface in the future.
        _strict_response_validation: bool = False,
    ) -> None:
        """Construct a new async AsyncDeasy client instance.

        This automatically infers the `x_token` argument from the `DEASY_API_KEY` environment variable if it is not provided.
        """
        if x_token is None:
            x_token = os.environ.get("DEASY_API_KEY")
        if x_token is None:
            raise DeasyError(
                "The x_token client option must be set either by passing x_token to the client or by setting the DEASY_API_KEY environment variable"
            )
        self.x_token = x_token

        self.x_user = x_user

        if base_url is None:
            base_url = os.environ.get("DEASY_BASE_URL")
        if base_url is None:
            base_url = f"https://prod-deasy-api-service-660949837227.us-east1.run.app/"

        super().__init__(
            version=__version__,
            base_url=base_url,
            max_retries=max_retries,
            timeout=timeout,
            http_client=http_client,
            custom_headers=default_headers,
            custom_query=default_query,
            _strict_response_validation=_strict_response_validation,
        )

        self.deasy_select = deasy_select.AsyncDeasySelectResource(self)
        self.classify_bulk = classify_bulk.AsyncClassifyBulkResource(self)
        self.classify = classify.AsyncClassifyResource(self)
        self.prepare_data = prepare_data.AsyncPrepareDataResource(self)
        self.suggest_schema = suggest_schema.AsyncSuggestSchemaResource(self)
        self.suggest_description = suggest_description.AsyncSuggestDescriptionResource(self)
        self.tags = tags.AsyncTagsResource(self)
        self.metadata = metadata.AsyncMetadataResource(self)
        self.vdb_connector = vdb_connector.AsyncVdbConnectorResource(self)
        self.llm_connector = llm_connector.AsyncLlmConnectorResource(self)
        self.dataslice = dataslice.AsyncDatasliceResource(self)
        self.schema = schema.AsyncSchemaResource(self)
        self.with_raw_response = AsyncDeasyWithRawResponse(self)
        self.with_streaming_response = AsyncDeasyWithStreamedResponse(self)

    @property
    @override
    def qs(self) -> Querystring:
        return Querystring(array_format="comma")

    @property
    @override
    def default_headers(self) -> dict[str, str | Omit]:
        return {
            **super().default_headers,
            "X-Stainless-Async": f"async:{get_async_library()}",
            "X-Token": self.x_token,
            "X-User": self.x_user,
            **self._custom_headers,
        }

    def copy(
        self,
        *,
        x_token: str | None = None,
        x_user: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = NOT_GIVEN,
        http_client: httpx.AsyncClient | None = None,
        max_retries: int | NotGiven = NOT_GIVEN,
        default_headers: Mapping[str, str] | None = None,
        set_default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        set_default_query: Mapping[str, object] | None = None,
        _extra_kwargs: Mapping[str, Any] = {},
    ) -> Self:
        """
        Create a new client instance re-using the same options given to the current client with optional overriding.
        """
        if default_headers is not None and set_default_headers is not None:
            raise ValueError("The `default_headers` and `set_default_headers` arguments are mutually exclusive")

        if default_query is not None and set_default_query is not None:
            raise ValueError("The `default_query` and `set_default_query` arguments are mutually exclusive")

        headers = self._custom_headers
        if default_headers is not None:
            headers = {**headers, **default_headers}
        elif set_default_headers is not None:
            headers = set_default_headers

        params = self._custom_query
        if default_query is not None:
            params = {**params, **default_query}
        elif set_default_query is not None:
            params = set_default_query

        http_client = http_client or self._client
        return self.__class__(
            x_token=x_token or self.x_token,
            x_user=x_user or self.x_user,
            base_url=base_url or self.base_url,
            timeout=self.timeout if isinstance(timeout, NotGiven) else timeout,
            http_client=http_client,
            max_retries=max_retries if is_given(max_retries) else self.max_retries,
            default_headers=headers,
            default_query=params,
            **_extra_kwargs,
        )

    # Alias for `copy` for nicer inline usage, e.g.
    # client.with_options(timeout=10).foo.create(...)
    with_options = copy

    @override
    def _make_status_error(
        self,
        err_msg: str,
        *,
        body: object,
        response: httpx.Response,
    ) -> APIStatusError:
        if response.status_code == 400:
            return _exceptions.BadRequestError(err_msg, response=response, body=body)

        if response.status_code == 401:
            return _exceptions.AuthenticationError(err_msg, response=response, body=body)

        if response.status_code == 403:
            return _exceptions.PermissionDeniedError(err_msg, response=response, body=body)

        if response.status_code == 404:
            return _exceptions.NotFoundError(err_msg, response=response, body=body)

        if response.status_code == 409:
            return _exceptions.ConflictError(err_msg, response=response, body=body)

        if response.status_code == 422:
            return _exceptions.UnprocessableEntityError(err_msg, response=response, body=body)

        if response.status_code == 429:
            return _exceptions.RateLimitError(err_msg, response=response, body=body)

        if response.status_code >= 500:
            return _exceptions.InternalServerError(err_msg, response=response, body=body)
        return APIStatusError(err_msg, response=response, body=body)


class DeasyWithRawResponse:
    def __init__(self, client: Deasy) -> None:
        self.deasy_select = deasy_select.DeasySelectResourceWithRawResponse(client.deasy_select)
        self.classify_bulk = classify_bulk.ClassifyBulkResourceWithRawResponse(client.classify_bulk)
        self.classify = classify.ClassifyResourceWithRawResponse(client.classify)
        self.prepare_data = prepare_data.PrepareDataResourceWithRawResponse(client.prepare_data)
        self.suggest_schema = suggest_schema.SuggestSchemaResourceWithRawResponse(client.suggest_schema)
        self.suggest_description = suggest_description.SuggestDescriptionResourceWithRawResponse(
            client.suggest_description
        )
        self.tags = tags.TagsResourceWithRawResponse(client.tags)
        self.metadata = metadata.MetadataResourceWithRawResponse(client.metadata)
        self.vdb_connector = vdb_connector.VdbConnectorResourceWithRawResponse(client.vdb_connector)
        self.llm_connector = llm_connector.LlmConnectorResourceWithRawResponse(client.llm_connector)
        self.dataslice = dataslice.DatasliceResourceWithRawResponse(client.dataslice)
        self.schema = schema.SchemaResourceWithRawResponse(client.schema)


class AsyncDeasyWithRawResponse:
    def __init__(self, client: AsyncDeasy) -> None:
        self.deasy_select = deasy_select.AsyncDeasySelectResourceWithRawResponse(client.deasy_select)
        self.classify_bulk = classify_bulk.AsyncClassifyBulkResourceWithRawResponse(client.classify_bulk)
        self.classify = classify.AsyncClassifyResourceWithRawResponse(client.classify)
        self.prepare_data = prepare_data.AsyncPrepareDataResourceWithRawResponse(client.prepare_data)
        self.suggest_schema = suggest_schema.AsyncSuggestSchemaResourceWithRawResponse(client.suggest_schema)
        self.suggest_description = suggest_description.AsyncSuggestDescriptionResourceWithRawResponse(
            client.suggest_description
        )
        self.tags = tags.AsyncTagsResourceWithRawResponse(client.tags)
        self.metadata = metadata.AsyncMetadataResourceWithRawResponse(client.metadata)
        self.vdb_connector = vdb_connector.AsyncVdbConnectorResourceWithRawResponse(client.vdb_connector)
        self.llm_connector = llm_connector.AsyncLlmConnectorResourceWithRawResponse(client.llm_connector)
        self.dataslice = dataslice.AsyncDatasliceResourceWithRawResponse(client.dataslice)
        self.schema = schema.AsyncSchemaResourceWithRawResponse(client.schema)


class DeasyWithStreamedResponse:
    def __init__(self, client: Deasy) -> None:
        self.deasy_select = deasy_select.DeasySelectResourceWithStreamingResponse(client.deasy_select)
        self.classify_bulk = classify_bulk.ClassifyBulkResourceWithStreamingResponse(client.classify_bulk)
        self.classify = classify.ClassifyResourceWithStreamingResponse(client.classify)
        self.prepare_data = prepare_data.PrepareDataResourceWithStreamingResponse(client.prepare_data)
        self.suggest_schema = suggest_schema.SuggestSchemaResourceWithStreamingResponse(client.suggest_schema)
        self.suggest_description = suggest_description.SuggestDescriptionResourceWithStreamingResponse(
            client.suggest_description
        )
        self.tags = tags.TagsResourceWithStreamingResponse(client.tags)
        self.metadata = metadata.MetadataResourceWithStreamingResponse(client.metadata)
        self.vdb_connector = vdb_connector.VdbConnectorResourceWithStreamingResponse(client.vdb_connector)
        self.llm_connector = llm_connector.LlmConnectorResourceWithStreamingResponse(client.llm_connector)
        self.dataslice = dataslice.DatasliceResourceWithStreamingResponse(client.dataslice)
        self.schema = schema.SchemaResourceWithStreamingResponse(client.schema)


class AsyncDeasyWithStreamedResponse:
    def __init__(self, client: AsyncDeasy) -> None:
        self.deasy_select = deasy_select.AsyncDeasySelectResourceWithStreamingResponse(client.deasy_select)
        self.classify_bulk = classify_bulk.AsyncClassifyBulkResourceWithStreamingResponse(client.classify_bulk)
        self.classify = classify.AsyncClassifyResourceWithStreamingResponse(client.classify)
        self.prepare_data = prepare_data.AsyncPrepareDataResourceWithStreamingResponse(client.prepare_data)
        self.suggest_schema = suggest_schema.AsyncSuggestSchemaResourceWithStreamingResponse(client.suggest_schema)
        self.suggest_description = suggest_description.AsyncSuggestDescriptionResourceWithStreamingResponse(
            client.suggest_description
        )
        self.tags = tags.AsyncTagsResourceWithStreamingResponse(client.tags)
        self.metadata = metadata.AsyncMetadataResourceWithStreamingResponse(client.metadata)
        self.vdb_connector = vdb_connector.AsyncVdbConnectorResourceWithStreamingResponse(client.vdb_connector)
        self.llm_connector = llm_connector.AsyncLlmConnectorResourceWithStreamingResponse(client.llm_connector)
        self.dataslice = dataslice.AsyncDatasliceResourceWithStreamingResponse(client.dataslice)
        self.schema = schema.AsyncSchemaResourceWithStreamingResponse(client.schema)


Client = Deasy

AsyncClient = AsyncDeasy



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Union, Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = [
    "MetadataGetDistributionsResponse",
    "SchemaNamesToCountDistributions",
    "SchemaNamesToCountDistributionsTagsInSchema",
]


class SchemaNamesToCountDistributionsTagsInSchema(BaseModel):
    description: str

    name: str

    output_type: str

    available_values: Optional[List[str]] = None

    created_at: Optional[datetime] = None

    date_format: Optional[str] = None

    examples: Optional[List[Union[str, Dict[str, object]]]] = None

    max_values: Union[int, str, List[object], None] = FieldInfo(alias="maxValues", default=None)

    neg_examples: Optional[List[str]] = None

    retry_feedback: Optional[Dict[str, object]] = None

    tag_id: Optional[str] = None

    tuned: Optional[int] = None

    updated_at: Optional[datetime] = None

    username: Optional[str] = None


class SchemaNamesToCountDistributions(BaseModel):
    count_distribution: Dict[str, int]

    tags_in_schema: List[SchemaNamesToCountDistributionsTagsInSchema]


class MetadataGetDistributionsResponse(BaseModel):
    schema_names_to_count_distributions: Dict[str, SchemaNamesToCountDistributions]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.


from .._models import BaseModel

__all__ = ["ConnectorResponse"]


class ConnectorResponse(BaseModel):
    profile_id: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["SharepointConnectorConfigParam"]


class SharepointConnectorConfigParam(TypedDict, total=False):
    client_id: Required[str]

    client_secret: Required[str]

    name: Required[str]

    sharepoint_site_name: Required[str]

    tenant_id: Required[str]

    type: Literal["SharepointDataSourceManager"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.


from .._models import BaseModel

__all__ = ["MetadataDeleteResponse"]


class MetadataDeleteResponse(BaseModel):
    chunk_deleted_count: int

    file_deleted_count: int



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List, Optional

import httpx

from ..types import (
    schema_list_params,
    schema_create_params,
    schema_delete_params,
    schema_update_params,
    schema_upsert_params,
)
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.schema_list_response import SchemaListResponse
from ..types.schema_operation_response import SchemaOperationResponse

__all__ = ["SchemaResource", "AsyncSchemaResource"]


class SchemaResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SchemaResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#accessing-raw-response-data-eg-headers
        """
        return SchemaResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SchemaResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#with_streaming_response
        """
        return SchemaResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        schema_name: str,
        schema_data: Optional[Dict[str, object]] | NotGiven = NOT_GIVEN,
        schema_description: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SchemaOperationResponse:
        """
        Create a new graph.

        Attributes:

            schema_name: The name of the schema to create.
            schema_description: The description of the schema to create.
            schema_data: The data of the schema to create.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/schema/create",
            body=maybe_transform(
                {
                    "schema_name": schema_name,
                    "schema_data": schema_data,
                    "schema_description": schema_description,
                },
                schema_create_params.SchemaCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SchemaOperationResponse,
        )

    def update(
        self,
        *,
        schema_name: str,
        schema_data: Optional[Dict[str, object]] | NotGiven = NOT_GIVEN,
        schema_description: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SchemaOperationResponse:
        """
        Update a graph in the database.

        Attributes:

            schema_name: The name of the schema to update.
            schema_description: The description of the schema to update.
            schema_data: The data of the schema to update.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/schema/update",
            body=maybe_transform(
                {
                    "schema_name": schema_name,
                    "schema_data": schema_data,
                    "schema_description": schema_description,
                },
                schema_update_params.SchemaUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SchemaOperationResponse,
        )

    def list(
        self,
        *,
        schema_ids: Optional[List[str]] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SchemaListResponse:
        """
        List all schemas for the authenticated user.

        Attributes:

            schema_ids: The ids of the schemas to retrieve.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/schema/list",
            body=maybe_transform({"schema_ids": schema_ids}, schema_list_params.SchemaListParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SchemaListResponse,
        )

    def delete(
        self,
        *,
        schema_name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SchemaOperationResponse:
        """
        Delete a schema by name.

        Attributes:

            schema_name: The name of the schema to delete.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._delete(
            "/schema/delete",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"schema_name": schema_name}, schema_delete_params.SchemaDeleteParams),
            ),
            cast_to=SchemaOperationResponse,
        )

    def upsert(
        self,
        *,
        schema_name: str,
        new_schema_name: Optional[str] | NotGiven = NOT_GIVEN,
        schema_data: Optional[Dict[str, object]] | NotGiven = NOT_GIVEN,
        schema_description: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SchemaOperationResponse:
        """
        Upsert a graph in the database.

        Attributes:

            schema_name: The stored name of the schema to upsert.
            new_schema_name: The new name of the schema to upsert.
            schema_description: The description of the schema to upsert.
            schema_data: The data of the schema to upsert.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/schema/upsert",
            body=maybe_transform(
                {
                    "schema_name": schema_name,
                    "new_schema_name": new_schema_name,
                    "schema_data": schema_data,
                    "schema_description": schema_description,
                },
                schema_upsert_params.SchemaUpsertParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SchemaOperationResponse,
        )


class AsyncSchemaResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSchemaResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#accessing-raw-response-data-eg-headers
        """
        return AsyncSchemaResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSchemaResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#with_streaming_response
        """
        return AsyncSchemaResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        schema_name: str,
        schema_data: Optional[Dict[str, object]] | NotGiven = NOT_GIVEN,
        schema_description: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SchemaOperationResponse:
        """
        Create a new graph.

        Attributes:

            schema_name: The name of the schema to create.
            schema_description: The description of the schema to create.
            schema_data: The data of the schema to create.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/schema/create",
            body=await async_maybe_transform(
                {
                    "schema_name": schema_name,
                    "schema_data": schema_data,
                    "schema_description": schema_description,
                },
                schema_create_params.SchemaCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SchemaOperationResponse,
        )

    async def update(
        self,
        *,
        schema_name: str,
        schema_data: Optional[Dict[str, object]] | NotGiven = NOT_GIVEN,
        schema_description: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SchemaOperationResponse:
        """
        Update a graph in the database.

        Attributes:

            schema_name: The name of the schema to update.
            schema_description: The description of the schema to update.
            schema_data: The data of the schema to update.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/schema/update",
            body=await async_maybe_transform(
                {
                    "schema_name": schema_name,
                    "schema_data": schema_data,
                    "schema_description": schema_description,
                },
                schema_update_params.SchemaUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SchemaOperationResponse,
        )

    async def list(
        self,
        *,
        schema_ids: Optional[List[str]] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SchemaListResponse:
        """
        List all schemas for the authenticated user.

        Attributes:

            schema_ids: The ids of the schemas to retrieve.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/schema/list",
            body=await async_maybe_transform({"schema_ids": schema_ids}, schema_list_params.SchemaListParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SchemaListResponse,
        )

    async def delete(
        self,
        *,
        schema_name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SchemaOperationResponse:
        """
        Delete a schema by name.

        Attributes:

            schema_name: The name of the schema to delete.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._delete(
            "/schema/delete",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"schema_name": schema_name}, schema_delete_params.SchemaDeleteParams
                ),
            ),
            cast_to=SchemaOperationResponse,
        )

    async def upsert(
        self,
        *,
        schema_name: str,
        new_schema_name: Optional[str] | NotGiven = NOT_GIVEN,
        schema_data: Optional[Dict[str, object]] | NotGiven = NOT_GIVEN,
        schema_description: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SchemaOperationResponse:
        """
        Upsert a graph in the database.

        Attributes:

            schema_name: The stored name of the schema to upsert.
            new_schema_name: The new name of the schema to upsert.
            schema_description: The description of the schema to upsert.
            schema_data: The data of the schema to upsert.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/schema/upsert",
            body=await async_maybe_transform(
                {
                    "schema_name": schema_name,
                    "new_schema_name": new_schema_name,
                    "schema_data": schema_data,
                    "schema_description": schema_description,
                },
                schema_upsert_params.SchemaUpsertParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SchemaOperationResponse,
        )


class SchemaResourceWithRawResponse:
    def __init__(self, schema: SchemaResource) -> None:
        self._schema = schema

        self.create = to_raw_response_wrapper(
            schema.create,
        )
        self.update = to_raw_response_wrapper(
            schema.update,
        )
        self.list = to_raw_response_wrapper(
            schema.list,
        )
        self.delete = to_raw_response_wrapper(
            schema.delete,
        )
        self.upsert = to_raw_response_wrapper(
            schema.upsert,
        )


class AsyncSchemaResourceWithRawResponse:
    def __init__(self, schema: AsyncSchemaResource) -> None:
        self._schema = schema

        self.create = async_to_raw_response_wrapper(
            schema.create,
        )
        self.update = async_to_raw_response_wrapper(
            schema.update,
        )
        self.list = async_to_raw_response_wrapper(
            schema.list,
        )
        self.delete = async_to_raw_response_wrapper(
            schema.delete,
        )
        self.upsert = async_to_raw_response_wrapper(
            schema.upsert,
        )


class SchemaResourceWithStreamingResponse:
    def __init__(self, schema: SchemaResource) -> None:
        self._schema = schema

        self.create = to_streamed_response_wrapper(
            schema.create,
        )
        self.update = to_streamed_response_wrapper(
            schema.update,
        )
        self.list = to_streamed_response_wrapper(
            schema.list,
        )
        self.delete = to_streamed_response_wrapper(
            schema.delete,
        )
        self.upsert = to_streamed_response_wrapper(
            schema.upsert,
        )


class AsyncSchemaResourceWithStreamingResponse:
    def __init__(self, schema: AsyncSchemaResource) -> None:
        self._schema = schema

        self.create = async_to_streamed_response_wrapper(
            schema.create,
        )
        self.update = async_to_streamed_response_wrapper(
            schema.update,
        )
        self.list = async_to_streamed_response_wrapper(
            schema.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            schema.delete,
        )
        self.upsert = async_to_streamed_response_wrapper(
            schema.upsert,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from .._models import BaseModel

__all__ = ["VdbConnectorGetDeleteStatsResponse"]


class VdbConnectorGetDeleteStatsResponse(BaseModel):
    dataslices_for_vdb: List[str]

    file_count_with_vdb: int



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.


from .._models import BaseModel

__all__ = ["MetadataUpsertResponse"]


class MetadataUpsertResponse(BaseModel):
    success: bool



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.


from .._models import BaseModel

__all__ = ["SchemaOperationResponse"]


class SchemaOperationResponse(BaseModel):
    schema_name: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from .._models import BaseModel
from .deasy_tag import DeasyTag

__all__ = ["TagUpsertResponse"]


class TagUpsertResponse(BaseModel):
    available_values_added: List[str]

    tag: DeasyTag

    tag_name: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union, Iterable, Optional
from typing_extensions import Literal, Required, TypedDict

__all__ = ["ConditionInputParam", "Tag"]


class Tag(TypedDict, total=False):
    name: Required[str]

    values: Required[List[Union[str, float]]]

    operator: Optional[str]


class ConditionInputParam(TypedDict, total=False):
    children: Optional[Iterable["ConditionInputParam"]]

    condition: Optional[Literal["AND", "OR"]]

    tag: Optional[Tag]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["PsqlConnectorConfig", "IndexInfo"]


class IndexInfo(BaseModel):
    found_indexes: List[str]

    total_indexes_found: int


class PsqlConnectorConfig(BaseModel):
    collection_name: str

    database_name: str

    db_user: str

    name: str

    password: str

    port: str

    url: str

    filename_key: Optional[str] = None

    index_info: Optional[IndexInfo] = None

    text_key: Optional[str] = None

    type: Optional[Literal["PSQLVectorDBManager"]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["S3ConnectorConfigParam"]


class S3ConnectorConfigParam(TypedDict, total=False):
    aws_access_key_id: Required[str]

    aws_secret_access_key: Required[str]

    bucket_name: Required[str]

    name: Required[str]

    type: Literal["S3DataSourceManager"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["OpenAIConfigParam"]


class OpenAIConfigParam(TypedDict, total=False):
    api_key: Required[str]

    rpm_completion: Required[int]

    tpm_completion: Required[int]

    llm_type: Annotated[str, PropertyInfo(alias="llmType")]

    rpm_embedding: Optional[int]

    temperature: float

    tpm_embedding: Optional[int]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, Union, Optional
from typing_extensions import TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .openai_config import OpenAIConfig

__all__ = ["LlmConnectorListResponse", "Connectors", "ConnectorsDeasyComputeConfig"]


class ConnectorsDeasyComputeConfig(BaseModel):
    llm_type: Optional[str] = FieldInfo(alias="llmType", default=None)


Connectors: TypeAlias = Union[ConnectorsDeasyComputeConfig, OpenAIConfig]


class LlmConnectorListResponse(BaseModel):
    connectors: Dict[str, Connectors]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from deasy_client import Deasy, AsyncDeasy

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestExport:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_export_metadata(self, client: Deasy) -> None:
        export = client.dataslice.export.export_metadata(
            vdb_profile_name="vdb_profile_name",
        )
        assert_matches_type(object, export, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_export_metadata_with_all_params(self, client: Deasy) -> None:
        export = client.dataslice.export.export_metadata(
            vdb_profile_name="vdb_profile_name",
            dataslice_id="dataslice_id",
            export_file_level=True,
            export_format="json",
            selected_metadata_fields=["string"],
        )
        assert_matches_type(object, export, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_export_metadata(self, client: Deasy) -> None:
        response = client.dataslice.export.with_raw_response.export_metadata(
            vdb_profile_name="vdb_profile_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        export = response.parse()
        assert_matches_type(object, export, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_export_metadata(self, client: Deasy) -> None:
        with client.dataslice.export.with_streaming_response.export_metadata(
            vdb_profile_name="vdb_profile_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            export = response.parse()
            assert_matches_type(object, export, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncExport:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_export_metadata(self, async_client: AsyncDeasy) -> None:
        export = await async_client.dataslice.export.export_metadata(
            vdb_profile_name="vdb_profile_name",
        )
        assert_matches_type(object, export, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_export_metadata_with_all_params(self, async_client: AsyncDeasy) -> None:
        export = await async_client.dataslice.export.export_metadata(
            vdb_profile_name="vdb_profile_name",
            dataslice_id="dataslice_id",
            export_file_level=True,
            export_format="json",
            selected_metadata_fields=["string"],
        )
        assert_matches_type(object, export, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_export_metadata(self, async_client: AsyncDeasy) -> None:
        response = await async_client.dataslice.export.with_raw_response.export_metadata(
            vdb_profile_name="vdb_profile_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        export = await response.parse()
        assert_matches_type(object, export, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_export_metadata(self, async_client: AsyncDeasy) -> None:
        async with async_client.dataslice.export.with_streaming_response.export_metadata(
            vdb_profile_name="vdb_profile_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            export = await response.parse()
            assert_matches_type(object, export, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from deasy_client import Deasy, AsyncDeasy
from deasy_client.types import (
    DatasliceListResponse,
    DatasliceCreateResponse,
    DatasliceDeleteResponse,
    DatasliceGetFilesResponse,
    DatasliceGetMetricsResponse,
    DatasliceGetFileCountResponse,
    DatasliceGetTagVdbDistributionResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestDataslice:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create(self, client: Deasy) -> None:
        dataslice = client.dataslice.create(
            dataslice_name="dataslice_name",
            graph_id="graph_id",
            latest_graph={"foo": "bar"},
            vdb_profile_name="vdb_profile_name",
        )
        assert_matches_type(DatasliceCreateResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create_with_all_params(self, client: Deasy) -> None:
        dataslice = client.dataslice.create(
            dataslice_name="dataslice_name",
            graph_id="graph_id",
            latest_graph={"foo": "bar"},
            vdb_profile_name="vdb_profile_name",
            condition={
                "children": [],
                "condition": "AND",
                "tag": {
                    "name": "name",
                    "values": ["string"],
                    "operator": "operator",
                },
            },
            data_points=0,
            description="description",
            status="status",
        )
        assert_matches_type(DatasliceCreateResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_create(self, client: Deasy) -> None:
        response = client.dataslice.with_raw_response.create(
            dataslice_name="dataslice_name",
            graph_id="graph_id",
            latest_graph={"foo": "bar"},
            vdb_profile_name="vdb_profile_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataslice = response.parse()
        assert_matches_type(DatasliceCreateResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_create(self, client: Deasy) -> None:
        with client.dataslice.with_streaming_response.create(
            dataslice_name="dataslice_name",
            graph_id="graph_id",
            latest_graph={"foo": "bar"},
            vdb_profile_name="vdb_profile_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataslice = response.parse()
            assert_matches_type(DatasliceCreateResponse, dataslice, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_list(self, client: Deasy) -> None:
        dataslice = client.dataslice.list()
        assert_matches_type(DatasliceListResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_list(self, client: Deasy) -> None:
        response = client.dataslice.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataslice = response.parse()
        assert_matches_type(DatasliceListResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_list(self, client: Deasy) -> None:
        with client.dataslice.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataslice = response.parse()
            assert_matches_type(DatasliceListResponse, dataslice, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_delete(self, client: Deasy) -> None:
        dataslice = client.dataslice.delete(
            dataslice_id="dataslice_id",
        )
        assert_matches_type(DatasliceDeleteResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_delete(self, client: Deasy) -> None:
        response = client.dataslice.with_raw_response.delete(
            dataslice_id="dataslice_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataslice = response.parse()
        assert_matches_type(DatasliceDeleteResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_delete(self, client: Deasy) -> None:
        with client.dataslice.with_streaming_response.delete(
            dataslice_id="dataslice_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataslice = response.parse()
            assert_matches_type(DatasliceDeleteResponse, dataslice, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_get_file_count(self, client: Deasy) -> None:
        dataslice = client.dataslice.get_file_count(
            vdb_profile_name="vdb_profile_name",
        )
        assert_matches_type(DatasliceGetFileCountResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_get_file_count_with_all_params(self, client: Deasy) -> None:
        dataslice = client.dataslice.get_file_count(
            vdb_profile_name="vdb_profile_name",
            condition={
                "children": [],
                "condition": "AND",
                "tag": {
                    "name": "name",
                    "values": ["string"],
                    "operator": "operator",
                },
            },
            dataslice_id="dataslice_id",
        )
        assert_matches_type(DatasliceGetFileCountResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_get_file_count(self, client: Deasy) -> None:
        response = client.dataslice.with_raw_response.get_file_count(
            vdb_profile_name="vdb_profile_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataslice = response.parse()
        assert_matches_type(DatasliceGetFileCountResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_get_file_count(self, client: Deasy) -> None:
        with client.dataslice.with_streaming_response.get_file_count(
            vdb_profile_name="vdb_profile_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataslice = response.parse()
            assert_matches_type(DatasliceGetFileCountResponse, dataslice, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_get_files(self, client: Deasy) -> None:
        dataslice = client.dataslice.get_files(
            dataslice_id="dataslice_id",
        )
        assert_matches_type(DatasliceGetFilesResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_get_files(self, client: Deasy) -> None:
        response = client.dataslice.with_raw_response.get_files(
            dataslice_id="dataslice_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataslice = response.parse()
        assert_matches_type(DatasliceGetFilesResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_get_files(self, client: Deasy) -> None:
        with client.dataslice.with_streaming_response.get_files(
            dataslice_id="dataslice_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataslice = response.parse()
            assert_matches_type(DatasliceGetFilesResponse, dataslice, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_get_metrics(self, client: Deasy) -> None:
        dataslice = client.dataslice.get_metrics()
        assert_matches_type(DatasliceGetMetricsResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_get_metrics_with_all_params(self, client: Deasy) -> None:
        dataslice = client.dataslice.get_metrics(
            dataslice_id="dataslice_id",
            file_names=["string"],
            node_ids=["string"],
            tags=["string"],
            vdb_profile_name="vdb_profile_name",
        )
        assert_matches_type(DatasliceGetMetricsResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_get_metrics(self, client: Deasy) -> None:
        response = client.dataslice.with_raw_response.get_metrics()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataslice = response.parse()
        assert_matches_type(DatasliceGetMetricsResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_get_metrics(self, client: Deasy) -> None:
        with client.dataslice.with_streaming_response.get_metrics() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataslice = response.parse()
            assert_matches_type(DatasliceGetMetricsResponse, dataslice, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_get_tag_vdb_distribution(self, client: Deasy) -> None:
        dataslice = client.dataslice.get_tag_vdb_distribution()
        assert_matches_type(DatasliceGetTagVdbDistributionResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_get_tag_vdb_distribution_with_all_params(self, client: Deasy) -> None:
        dataslice = client.dataslice.get_tag_vdb_distribution(
            dataslice_id="dataslice_id",
            vdb_profile_name="vdb_profile_name",
        )
        assert_matches_type(DatasliceGetTagVdbDistributionResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_get_tag_vdb_distribution(self, client: Deasy) -> None:
        response = client.dataslice.with_raw_response.get_tag_vdb_distribution()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataslice = response.parse()
        assert_matches_type(DatasliceGetTagVdbDistributionResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_get_tag_vdb_distribution(self, client: Deasy) -> None:
        with client.dataslice.with_streaming_response.get_tag_vdb_distribution() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataslice = response.parse()
            assert_matches_type(DatasliceGetTagVdbDistributionResponse, dataslice, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncDataslice:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create(self, async_client: AsyncDeasy) -> None:
        dataslice = await async_client.dataslice.create(
            dataslice_name="dataslice_name",
            graph_id="graph_id",
            latest_graph={"foo": "bar"},
            vdb_profile_name="vdb_profile_name",
        )
        assert_matches_type(DatasliceCreateResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncDeasy) -> None:
        dataslice = await async_client.dataslice.create(
            dataslice_name="dataslice_name",
            graph_id="graph_id",
            latest_graph={"foo": "bar"},
            vdb_profile_name="vdb_profile_name",
            condition={
                "children": [],
                "condition": "AND",
                "tag": {
                    "name": "name",
                    "values": ["string"],
                    "operator": "operator",
                },
            },
            data_points=0,
            description="description",
            status="status",
        )
        assert_matches_type(DatasliceCreateResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncDeasy) -> None:
        response = await async_client.dataslice.with_raw_response.create(
            dataslice_name="dataslice_name",
            graph_id="graph_id",
            latest_graph={"foo": "bar"},
            vdb_profile_name="vdb_profile_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataslice = await response.parse()
        assert_matches_type(DatasliceCreateResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncDeasy) -> None:
        async with async_client.dataslice.with_streaming_response.create(
            dataslice_name="dataslice_name",
            graph_id="graph_id",
            latest_graph={"foo": "bar"},
            vdb_profile_name="vdb_profile_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataslice = await response.parse()
            assert_matches_type(DatasliceCreateResponse, dataslice, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_list(self, async_client: AsyncDeasy) -> None:
        dataslice = await async_client.dataslice.list()
        assert_matches_type(DatasliceListResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncDeasy) -> None:
        response = await async_client.dataslice.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataslice = await response.parse()
        assert_matches_type(DatasliceListResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncDeasy) -> None:
        async with async_client.dataslice.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataslice = await response.parse()
            assert_matches_type(DatasliceListResponse, dataslice, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_delete(self, async_client: AsyncDeasy) -> None:
        dataslice = await async_client.dataslice.delete(
            dataslice_id="dataslice_id",
        )
        assert_matches_type(DatasliceDeleteResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncDeasy) -> None:
        response = await async_client.dataslice.with_raw_response.delete(
            dataslice_id="dataslice_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataslice = await response.parse()
        assert_matches_type(DatasliceDeleteResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncDeasy) -> None:
        async with async_client.dataslice.with_streaming_response.delete(
            dataslice_id="dataslice_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataslice = await response.parse()
            assert_matches_type(DatasliceDeleteResponse, dataslice, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_get_file_count(self, async_client: AsyncDeasy) -> None:
        dataslice = await async_client.dataslice.get_file_count(
            vdb_profile_name="vdb_profile_name",
        )
        assert_matches_type(DatasliceGetFileCountResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_get_file_count_with_all_params(self, async_client: AsyncDeasy) -> None:
        dataslice = await async_client.dataslice.get_file_count(
            vdb_profile_name="vdb_profile_name",
            condition={
                "children": [],
                "condition": "AND",
                "tag": {
                    "name": "name",
                    "values": ["string"],
                    "operator": "operator",
                },
            },
            dataslice_id="dataslice_id",
        )
        assert_matches_type(DatasliceGetFileCountResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_get_file_count(self, async_client: AsyncDeasy) -> None:
        response = await async_client.dataslice.with_raw_response.get_file_count(
            vdb_profile_name="vdb_profile_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataslice = await response.parse()
        assert_matches_type(DatasliceGetFileCountResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_get_file_count(self, async_client: AsyncDeasy) -> None:
        async with async_client.dataslice.with_streaming_response.get_file_count(
            vdb_profile_name="vdb_profile_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataslice = await response.parse()
            assert_matches_type(DatasliceGetFileCountResponse, dataslice, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_get_files(self, async_client: AsyncDeasy) -> None:
        dataslice = await async_client.dataslice.get_files(
            dataslice_id="dataslice_id",
        )
        assert_matches_type(DatasliceGetFilesResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_get_files(self, async_client: AsyncDeasy) -> None:
        response = await async_client.dataslice.with_raw_response.get_files(
            dataslice_id="dataslice_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataslice = await response.parse()
        assert_matches_type(DatasliceGetFilesResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_get_files(self, async_client: AsyncDeasy) -> None:
        async with async_client.dataslice.with_streaming_response.get_files(
            dataslice_id="dataslice_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataslice = await response.parse()
            assert_matches_type(DatasliceGetFilesResponse, dataslice, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_get_metrics(self, async_client: AsyncDeasy) -> None:
        dataslice = await async_client.dataslice.get_metrics()
        assert_matches_type(DatasliceGetMetricsResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_get_metrics_with_all_params(self, async_client: AsyncDeasy) -> None:
        dataslice = await async_client.dataslice.get_metrics(
            dataslice_id="dataslice_id",
            file_names=["string"],
            node_ids=["string"],
            tags=["string"],
            vdb_profile_name="vdb_profile_name",
        )
        assert_matches_type(DatasliceGetMetricsResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_get_metrics(self, async_client: AsyncDeasy) -> None:
        response = await async_client.dataslice.with_raw_response.get_metrics()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataslice = await response.parse()
        assert_matches_type(DatasliceGetMetricsResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_get_metrics(self, async_client: AsyncDeasy) -> None:
        async with async_client.dataslice.with_streaming_response.get_metrics() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataslice = await response.parse()
            assert_matches_type(DatasliceGetMetricsResponse, dataslice, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_get_tag_vdb_distribution(self, async_client: AsyncDeasy) -> None:
        dataslice = await async_client.dataslice.get_tag_vdb_distribution()
        assert_matches_type(DatasliceGetTagVdbDistributionResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_get_tag_vdb_distribution_with_all_params(self, async_client: AsyncDeasy) -> None:
        dataslice = await async_client.dataslice.get_tag_vdb_distribution(
            dataslice_id="dataslice_id",
            vdb_profile_name="vdb_profile_name",
        )
        assert_matches_type(DatasliceGetTagVdbDistributionResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_get_tag_vdb_distribution(self, async_client: AsyncDeasy) -> None:
        response = await async_client.dataslice.with_raw_response.get_tag_vdb_distribution()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataslice = await response.parse()
        assert_matches_type(DatasliceGetTagVdbDistributionResponse, dataslice, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_get_tag_vdb_distribution(self, async_client: AsyncDeasy) -> None:
        async with async_client.dataslice.with_streaming_response.get_tag_vdb_distribution() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataslice = await response.parse()
            assert_matches_type(DatasliceGetTagVdbDistributionResponse, dataslice, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict

from .._models import BaseModel

__all__ = ["DatasliceDeleteResponse"]


class DatasliceDeleteResponse(BaseModel):
    data: Dict[str, object]

    message: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict

from .._models import BaseModel

__all__ = ["ClassifyClassifyFilesResponse"]


class ClassifyClassifyFilesResponse(BaseModel):
    message: str

    output: Dict[str, object]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional
from typing_extensions import Required, TypedDict

__all__ = ["MetadataGetDistributionsParams"]


class MetadataGetDistributionsParams(TypedDict, total=False):
    analysis_level: Required[str]

    vdb_profile_name: Required[str]

    schema_names: Optional[List[str]]

    tag_names: Optional[List[str]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from deasy_client import Deasy, AsyncDeasy
from deasy_client.types import SuggestDescriptionCreateResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestSuggestDescription:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create(self, client: Deasy) -> None:
        suggest_description = client.suggest_description.create(
            tag_name="tag_name",
            vdb_profile_name="vdb_profile_name",
        )
        assert_matches_type(SuggestDescriptionCreateResponse, suggest_description, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create_with_all_params(self, client: Deasy) -> None:
        suggest_description = client.suggest_description.create(
            tag_name="tag_name",
            vdb_profile_name="vdb_profile_name",
            available_values=["string"],
            context="context",
            current_description="current_description",
            llm_profile_name="llm_profile_name",
        )
        assert_matches_type(SuggestDescriptionCreateResponse, suggest_description, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_create(self, client: Deasy) -> None:
        response = client.suggest_description.with_raw_response.create(
            tag_name="tag_name",
            vdb_profile_name="vdb_profile_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        suggest_description = response.parse()
        assert_matches_type(SuggestDescriptionCreateResponse, suggest_description, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_create(self, client: Deasy) -> None:
        with client.suggest_description.with_streaming_response.create(
            tag_name="tag_name",
            vdb_profile_name="vdb_profile_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            suggest_description = response.parse()
            assert_matches_type(SuggestDescriptionCreateResponse, suggest_description, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncSuggestDescription:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create(self, async_client: AsyncDeasy) -> None:
        suggest_description = await async_client.suggest_description.create(
            tag_name="tag_name",
            vdb_profile_name="vdb_profile_name",
        )
        assert_matches_type(SuggestDescriptionCreateResponse, suggest_description, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncDeasy) -> None:
        suggest_description = await async_client.suggest_description.create(
            tag_name="tag_name",
            vdb_profile_name="vdb_profile_name",
            available_values=["string"],
            context="context",
            current_description="current_description",
            llm_profile_name="llm_profile_name",
        )
        assert_matches_type(SuggestDescriptionCreateResponse, suggest_description, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncDeasy) -> None:
        response = await async_client.suggest_description.with_raw_response.create(
            tag_name="tag_name",
            vdb_profile_name="vdb_profile_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        suggest_description = await response.parse()
        assert_matches_type(SuggestDescriptionCreateResponse, suggest_description, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncDeasy) -> None:
        async with async_client.suggest_description.with_streaming_response.create(
            tag_name="tag_name",
            vdb_profile_name="vdb_profile_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            suggest_description = await response.parse()
            assert_matches_type(SuggestDescriptionCreateResponse, suggest_description, path=["response"])

        assert cast(Any, response.is_closed) is True
